@@ -79,5 +79,37 @@ class FunctionalThreadedFuncActor(FunctionalActor):
             result = await self.loop.run_in_executor(self.threadpool, self._assign_threaded, args, kwargs, self.loop, assign_handler, self.provide_handler)
             shrinked_returns = await shrinkOutputs(self.template.node, result) if self.shrinkOutputs else result
             await assign_handler.pass_result(shrinked_returns)
+        except Exception as e:
+            await assign_handler.pass_exception(e)
+
+
+
+class FunctionalThreadedGenActor(FunctionalActor):
+    nworkers = 5
+
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self.threadpool = ThreadPoolExecutor(self.nworkers)
+
+    def assign(self, *args, **kwargs):
+        raise NotImplementedError("")   
+
+
+    def _assign_threaded(self, args, kwargs, loop, assign_handler, provide_handler):
+        assign_handler_context.set(assign_handler)
+        provide_handler_context.set(provide_handler)
+        loop_context.set(loop)
+        for result in self.assign(*args, **kwargs):
+            lastresult = shrinkOutputsSync(self.template.node, result) if self.shrinkOutputs else result
+            print(result)
+            loop.create_task(assign_handler.pass_result(lastresult))
+
+        loop_context.set(None)
+
+
+    async def _assign(self, assign_handler: AssignHandler, args, kwargs):
+        try:
+            result = await self.loop.run_in_executor(self.threadpool, self._assign_threaded, args, kwargs, self.loop, assign_handler, self.provide_handler)
+            await assign_handler.pass_done()
         except Exception as e:
             await assign_handler.pass_exception(e)
\ No newline at end of file
