@@ -126,11 +126,12 @@ class Reservation:
                     break
 
         except asyncio.CancelledError as e:
-            self.log("[red] Cancelled")
+            self.log("ASSIGN", "Cancelled")
+            print("Canncelled")
             raise e
 
         except AssignmentException as e:
-            self.log("[red]ASSIGN", str(e))
+            self.log("ASSIGN", str(e))
             if not self.ignore_node_exceptions: raise e
 
         
@@ -218,9 +219,9 @@ class Reservation:
     
     def assign(self, *args, bypass_shrink=False, bypass_expand=False, persist=True, **kwargs):
         if self.in_sync:
-            return self.loop.run_until_complete(self.assign_async(*args, bypass_shrink=False, bypass_expand=False, persist=persist, **kwargs))
+            return self.loop.run_until_complete(self.assign_async(*args, bypass_shrink=bypass_shrink, bypass_expand=bypass_expand, persist=persist, **kwargs))
         else:
-            return self.assign_async(*args, bypass_shrink=False, bypass_expand=False, persist=persist, **kwargs)
+            return self.assign_async(*args, bypass_shrink=bypass_shrink, bypass_expand=bypass_expand, persist=persist, **kwargs)
 
     def __enter__(self):
         self.in_sync = True
