@@ -9,6 +9,7 @@ NEGOTIATION_GQL = TypedGQL("""
       $inward: String,
       $outward: String,
       $port: Int,
+      $internal: Boolean,
       $version: String,
       $pointType: DataPointTypeInput,
       $needsNegotiation: Boolean
@@ -19,6 +20,7 @@ NEGOTIATION_GQL = TypedGQL("""
       inward: $inward,
       outward: $outward,
       port: $port,
+      internal: $internal,
       version: $version,
       pointType: $pointType,
       needsNegotiation: $needsNegotiation
